Struct ZwpLinuxExplicitSynchronizationV1
pub struct ZwpLinuxExplicitSynchronizationV1 { /* private fields */ }wayland and Linux only.Expand description
protocol for providing explicit synchronization
This global is a factory interface, allowing clients to request explicit synchronization for buffers on a per-surface basis.
See zwp_linux_surface_synchronization_v1 for more information.
This interface is derived from Chromium’s zcr_linux_explicit_synchronization_v1.
Note: this protocol is superseded by linux-drm-syncobj.
Warning! The protocol described in this file is experimental and backward incompatible changes may be made. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes are done by bumping the version number in the protocol and interface names and resetting the interface version. Once the protocol is to be declared stable, the ‘z’ prefix and the version number in the protocol and interface names are removed and the interface version number is reset.
See also the Request enum for this interface.